<?php

//$content_width is required even though this is a variable-width theme
if ( ! isset( $dw_grayscale_content_width ) ) {
	$dw_grayscale_content_width = 400;
}

function dw_grayscale_sanitize_html( $html ) {
	return wp_filter_post_kses( $html );
}

function dw_grayscale_sanitize_checkbox( $input ) {
	return ( ( isset( $input ) && true === $input ) ? true : false );
}

//makes replying look neat
if ( ! function_exists( 'dw_grayscale_threaded_comments' ) ) :
	function dw_grayscale_threaded_comments() {
		if ( get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'dw_grayscale_threaded_comments' );
endif;

// displays "Comments are closed" instead of comment form when comments are closed.
if ( ! function_exists( 'dw_grayscale_closed_comments' ) ) :
	function dw_grayscale_closed_comments() {
		echo '<p>', esc_html__( 'Comments are closed.', 'dw-grayscale' ), '</p>';
	}
	add_action( 'comment_form_comments_closed', 'dw_grayscale_closed_comments' );
endif;

if ( ! function_exists( 'dw_grayscale_setup' ) ) :
	function dw_grayscale_setup() {
		load_theme_textdomain( 'dw-grayscale', get_template_directory() . '/languages' );
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 248,
				'width'       => 688,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
		add_theme_support( 'title-tag' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'customize-selective-regrayscale-widgets' );
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 150, 150 );
		add_image_size( 'dw-grayscale-single-post-thumbnail', 9999, 9999 );
		add_image_size( 'dw-grayscale-homepage-featured', 350, 350 );
		add_theme_support(
			'starter-content', 
			array(
				'widgets' => array(
					'left-sidebar'  => array(
						array(
							'text',
							array(
								'title' => esc_html__( 'First Sidebar', 'dw-grayscale' ),
								'text'  => _x( 'This is some text in the first sidebar.', 'Theme Starter Content', 'dw-grayscale' ),
							),
						),
					),
					'right-sidebar' => array(
						array(
							'text',
							array(
								'title' => esc_html__( 'Second Sidebar', 'dw-grayscale' ),
								'text'  => _x( 'This is some text in the second sidebar.', 'Theme Starter Content', 'dw-grayscale' ),
							),
						),
					),
					'center-block'  => array(
						array(
							'text',
							array(
								'title' => esc_html__( 'Center Block', 'dw-grayscale' ),
								'text'  => _x( 'This is some text in the center block.', 'Theme Starter Content', 'dw-grayscale' ),
							),
						),
					),
				),
			)
		);
	}
	add_action( 'after_setup_theme', 'dw_grayscale_setup' );
endif;

if ( ! function_exists( 'dw_grayscale_register_menu' ) ) :
	function dw_grayscale_register_menu() {
		register_nav_menus(
			array(
				'top_header_menu' => esc_html__( 'Top Header Menu', 'dw-grayscale' ),
			)
		);
	}
	add_action( 'init', 'dw_grayscale_register_menu' );
endif;

if ( ! function_exists( 'dw_grayscale_stylesheet' ) ) :
	function dw_grayscale_stylesheet() {
		wp_enqueue_style( 'dw-grayscale-style', get_stylesheet_directory_uri() . '/style.css', array(), wp_get_theme()->version );
	}
	add_action( 'wp_enqueue_scripts', 'dw_grayscale_stylesheet' );
endif;

if ( ! function_exists( 'dw_grayscale_sidebars' ) ) :
	// register the sidebars
	function dw_grayscale_sidebars() {
		register_sidebar( 
			array(
				'name' => __( 'Left Sidebar 1', 'dw-grayscale' ),
				'id'   => 'left-sidebar',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Center Block 1', 'dw-grayscale' ),
				'id'   => 'center-block',
			)
		);
		register_sidebar(
			array(
				'name' => __( 'Right Sidebar 1', 'dw-grayscale' ),
				'id'   => 'right-sidebar',
			)
		);
	}
	add_action( 'widgets_init', 'dw_grayscale_sidebars' );
endif;

// display information about a post under the post title
if ( ! function_exists( 'dw_grayscale_post_meta' ) ) :
	function dw_grayscale_post_meta() {
		echo '<div class="meta">';
		if ( get_post_type() === 'page' ) :
			printf(
				/* translators: %s = author */
				esc_html__( 'Posted by %s', 'dw-grayscale' ),
				get_the_author()
			);
		elseif ( has_category() ) :
			printf(
				/* translators: %1$s = date, %2$s = categories, %3$s = author */
				esc_html__( 'Posted on %1$s in %2$s by %3$s', 'dw-grayscale' ),
				get_the_date(),
				wp_kses_post( get_the_category_list( ',' ) ),
				get_the_author()
			);
		else :
			printf(
				/* translators: %1$s = date, %2$s = author */
				esc_html__( 'Posted on %1$s by %2$s', 'dw-grayscale' ),
				get_the_date(),
				get_the_author()
			);
		endif;
		edit_post_link( _x( 'Edit', 'verb', 'dw-grayscale' ), ' | ' );
		if ( get_post_type() !== 'page' && has_tag() ) :
			echo '<br>';
			the_tags();
		endif;
		echo '</div>';
	}
endif;

// change the archive title to show the search query when showing the archive title on a search result page.
if ( ! function_exists( 'dw_grayscale_search_title' ) ) :
	function dw_grayscale_search_title( $title ) {
		if ( is_search() ) {
			/* translators: %s = search query */
			$title = sprintf( __( 'Search: %s', 'dw-grayscale' ), get_search_query() );
		}
		return $title;
	}
	add_filter( 'get_the_archive_title', 'dw_grayscale_search_title' );
endif;

function dw_grayscale_google_fonts() {
	wp_enqueue_style( 'google-fonts', 'https://fonts.googleapis.com/css2?family=Electrolize&display=swap', array(), wp_get_theme()->version );
}
add_action( 'wp_enqueue_scripts', 'dw_grayscale_google_fonts' );

/**
 * Enqueue scripts
 */
function dw_grayscale_enqueue_scripts() {
	wp_enqueue_script( 'dw-grayscale-header-clock', get_template_directory_uri() . '/js/dw-grayscale-header-clock.js', array(), wp_get_theme()->version, true );
	wp_enqueue_script( 'dw-grayscale-top-button', get_template_directory_uri() . '/js/dw-grayscale-top-button.js', array(), wp_get_theme()->version, true );
	wp_enqueue_script( 'dw-grayscale-navigation', get_template_directory_uri() . '/js/dw-grayscale-navigation.js', array( 'jquery' ), '20141205', true );
}
add_action( 'wp_enqueue_scripts', 'dw_grayscale_enqueue_scripts' );

// Add Footer Text Box section to customize
function dw_grayscale_fcontent( $wp_customize ) {
	$wp_customize->add_section(
		'dw-grayscale-fcontent-section', 
		array(
			'title' => __( 'Footer Text Box', 'dw-grayscale' ),
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-fcontent-text-control', 
			array(
				'type'        => 'button',
				'settings'    => array(),
				'label'       => __( 'Footer HTML Text Box:', 'dw-grayscale' ),
				'priority'    => 10,
				'section'     => 'dw-grayscale-fcontent-section',
				'input_attrs' => array(
					'value'   => __( 'Get Premium For This Feature!', 'dw-grayscale' ),
					'class'   => 'button-secondary',
					'onclick' => "window.open('https://www.designwicked.com/premium-grayscale', '_blank')",
				),
			)
		)
	);
}

add_action( 'customize_register', 'dw_grayscale_fcontent' );

// Premium Upgrade Section
function dw_grayscale_procontent( 
	$wp_customize ) {
	$wp_customize->add_section(
		'pro_sec', 
		array(
			'title'       => __( 'GET PREMIUM VERSION', 'dw-grayscale' ),
			'description' => '',
			'priority'    => 10,
			'capability'  => 'edit_theme_options',
		) 
	);
	
	$wp_customize->add_control(
		'button_id',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'priority'    => 10,
			'section'     => 'pro_sec',
			'input_attrs' => array(
				'value'   => __( 'BUY PREMIUM VERSION', 'dw-grayscale' ),
				'class'   => 'button-primary',
				'onclick' => "window.open('https://www.designwicked.com/premium-grayscale', '_blank')",
			),
		)
	);

	$wp_customize->add_control(
		'label',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'Premium Features:', 'dw-grayscale' ),
			'priority'    => 10,
			'section'     => 'pro_sec',
			'input_attrs' => array(
				'value'   => __( '12 More Widget Blocks', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/wordpress-themes', '_blank')",
			),
		)
	);
	
	$wp_customize->add_control(
		'label1',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'priority'    => 10,
			'section'     => 'pro_sec',
			'input_attrs' => array(
				'value'   => __( 'Footer HTML/Text Content Area', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/wordpress-themes', '_blank')",
			),
		)
	);
	
	$wp_customize->add_control(
		'label2',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'priority'    => 10,
			'section'     => 'pro_sec',
			'input_attrs' => array(
				'value'   => __( 'Top Header and Bottom Footer Length Widget Area', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/wordpress-themes', '_blank')",
			),
		)
	);
	
	$wp_customize->add_control(
		'label3',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'priority'    => 10,
			'section'     => 'pro_sec',
			'input_attrs' => array(
				'value'   => __( 'bbPress Matching Forum Style', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/wordpress-themes', '_blank')",
			),
		)
	);
	
	$wp_customize->add_control(
		'label4',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'priority'    => 10,
			'section'     => 'pro_sec',
			'input_attrs' => array(
				'value'   => __( 'And More!', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/wordpress-themes', '_blank')",
			),
		)
	);
	
	$wp_customize->add_control(
		'label5',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'FOR MORE DW THEMES:', 'dw-grayscale' ),
			'priority'    => 10,
			'section'     => 'pro_sec',
			'input_attrs' => array(
				'value'   => __( 'CLICK HERE!', 'dw-grayscale' ),
				'class'   => 'button-primary',
				'onclick' => "window.open('https://www.designwicked.com/wordpress-themes', '_blank')",
			),
		)
	);
	
}
	
add_action( 'customize_register', 'dw_grayscale_procontent' );

// Header Nav
function dw_grayscale_hnav( $wp_customize ) {
	$wp_customize->add_section(
		'dw-grayscale-hnav-section',
		array(
			'title' => esc_html__( 'Header Navigation', 'dw-grayscale' ),
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-linkname1',
		array(
			'default'           => esc_html__( 'Link 1', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);


	$wp_customize->add_control( 
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-linkname1',
			array(
				'label'       => esc_html__( 'Link 1 Name:', 'dw-grayscale' ),
				'section'     => 'dw-grayscale-hnav-section',
				'description' => esc_html__( 'The visible name of the link on the button.', 'dw-grayscale' ),
				'settings'    => 'dw-grayscale-hnav-linkname1',
				'type'        => 'text',
			)
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-link1',
		array(
			'default'           => esc_html__( 'http://', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);


	$wp_customize->add_control( 
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-link1',
			array(
				'label'       => esc_html__( 'Link 1 Address:', 'dw-grayscale' ),
				'section'     => 'dw-grayscale-hnav-section',
				'description' => esc_html__( 'You can use /address to point to a directory, or just put a full link including http://', 'dw-grayscale' ),
				'settings'    => 'dw-grayscale-hnav-link1',
				'type'        => 'text',
			)
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-linkname2',
		array(
			'default'           => esc_html__( 'Link 2', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-linkname2',
			array(
				'label'    => esc_html__( 'Link 2 Name:', 'dw-grayscale' ),
				'section'  => 'dw-grayscale-hnav-section',
				'settings' => 'dw-grayscale-hnav-linkname2',
				'type'     => 'text',
			)
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-link2',
		array(
			'default'           => esc_html__( 'http://', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-link2',
			array(
				'label'    => esc_html__( 'Link 2 Address:', 'dw-grayscale' ),
				'section'  => 'dw-grayscale-hnav-section',
				'settings' => 'dw-grayscale-hnav-link2',
				'type'     => 'text',
			)
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-linkname3',
		array(
			'default'           => esc_html__( 'Link 3', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-linkname3',
			array(
				'label'    => esc_html__( 'Link 3 Name:', 'dw-grayscale' ),
				'section'  => 'dw-grayscale-hnav-section',
				'settings' => 'dw-grayscale-hnav-linkname3',
				'type'     => 'text',
			)
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-link3',
		array(
			'default'           => esc_html__( 'http://', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-link3',
			array(
				'label'    => esc_html__( 'Link 3 Address:', 'dw-grayscale' ),
				'section'  => 'dw-grayscale-hnav-section',
				'settings' => 'dw-grayscale-hnav-link3',
				'type'     => 'text',
			)
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-linkname4',
		array(
			'default'           => esc_html__( 'Link 4', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);


	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-linkname4',
			array(
				'label'    => esc_html__( 'Link 4 Name:', 'dw-grayscale' ),
				'section'  => 'dw-grayscale-hnav-section',
				'settings' => 'dw-grayscale-hnav-linkname4',
				'type'     => 'text',
			)
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-link4',
		array(
			'default'           => esc_html__( 'http://', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-link4',
			array(
				'label'    => esc_html__( 'Link 4 Address:', 'dw-grayscale' ),
				'section'  => 'dw-grayscale-hnav-section',
				'settings' => 'dw-grayscale-hnav-link4',
				'type'     => 'text',
			)
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-linkname5',
		array(
			'default'           => esc_html__( 'Link 5', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);


	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-linkname5',
			array(
				'label'    => esc_html__( 'Link 5 Name:', 'dw-grayscale' ),
				'section'  => 'dw-grayscale-hnav-section',
				'settings' => 'dw-grayscale-hnav-linkname5',
				'type'     => 'text',
			)
		)
	);

	$wp_customize->add_setting(
		'dw-grayscale-hnav-link5',
		array(
			'default'           => esc_html__( 'http://', 'dw-grayscale' ),
			'sanitize_callback' => 'dw_grayscale_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'dw-grayscale-hnav-control-link5',
			array(
				'label'    => esc_html__( 'Link 5 Address:', 'dw-grayscale' ),
				'section'  => 'dw-grayscale-hnav-section',
				'settings' => 'dw-grayscale-hnav-link5',
				'type'     => 'text',
			)
		)
	);
}
add_action( 'customize_register', 'dw_grayscale_hnav' );

//Social Bar
function dw_grayscale_socialbar( $wp_customize ) {
	$wp_customize->add_section(
		'dw_grayscale_socialbar_section',
		array(
			'title'       => esc_html__( 'Text And Social Bar', 'dw-grayscale' ),
			'description' => esc_html__( 'Add Social Bar Content', 'dw-grayscale' ),
			'priority'    => null,
		)
	);
	
	//Topbar Text
	$wp_customize->add_setting(
		'dw_grayscale_socialbar_section_text',
		array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'dw_grayscale_socialbar_section_text',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'Header Bar Text:', 'dw-grayscale' ),
			'priority'    => 10,
			'section'     => 'dw_grayscale_socialbar_section',
			'input_attrs' => array(
				'value'   => __( 'Get Premium For This Feature!', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/premium-grayscale', '_blank')",
			),
		)
	);
	
	//Social Icons
	$wp_customize->add_setting(
		'dw_grayscale_facebook_url',
		array(
			'default'           => '/',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'dw_grayscale_facebook_url',
		array(
			'label'       => esc_html__( 'Facebook Link:', 'dw-grayscale' ),
			'description' => esc_html__( '--Erase address, then leave blank, to make icons disappear.', 'dw-grayscale' ),
			'section'     => 'dw_grayscale_socialbar_section',
			'setting'     => 'dw_grayscale_facebook_url',
			'type'        => 'url',
		)
	);

	$wp_customize->add_setting(
		'dw_grayscale_gplus_url',
		array(
			'default'           => '/',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'dw_grayscale_gplus_url',
		array(
			'label'   => esc_html__( 'Google+ Link:', 'dw-grayscale' ),
			'section' => 'dw_grayscale_socialbar_section',
			'setting' => 'dw_grayscale_gplus_url',
			'type'    => 'url',
		)
	);
	
	$wp_customize->add_control(
		'labels',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'Twitter Link:', 'dw-grayscale' ),
			'priority'    => 10,
			'section'     => 'dw_grayscale_socialbar_section',
			'input_attrs' => array(
				'value'   => __( 'Get Premium For This Feature!', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/premium-grayscale', '_blank')",
			),
		)
	);
	
	$wp_customize->add_control(
		'labels1',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'Linkedin Link:', 'dw-grayscale' ),
			'priority'    => 10,
			'section'     => 'dw_grayscale_socialbar_section',
			'input_attrs' => array(
				'value'   => __( 'Get Premium For This Feature!', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/premium-grayscale', '_blank')",
			),
		)
	);
	
	$wp_customize->add_control(
		'labels2',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'Instagram Link:', 'dw-grayscale' ),
			'priority'    => 10,
			'section'     => 'dw_grayscale_socialbar_section',
			'input_attrs' => array(
				'value'   => __( 'Get Premium For This Feature!', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/premium-grayscale', '_blank')",
			),
		)
	);
	
	$wp_customize->add_control(
		'labels3',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'Youtube Link:', 'dw-grayscale' ),
			'priority'    => 10,
			'section'     => 'dw_grayscale_socialbar_section',
			'input_attrs' => array(
				'value'   => __( 'Get Premium For This Feature!', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/premium-grayscale', '_blank')",
			),
		)
	);
	
	$wp_customize->add_control(
		'labels4',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'Discord Link:', 'dw-grayscale' ),
			'priority'    => 10,
			'section'     => 'dw_grayscale_socialbar_section',
			'input_attrs' => array(
				'value'   => __( 'Get Premium For This Feature!', 'dw-grayscale' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.designwicked.com/premium-grayscale', '_blank')",
			),
		)
	);
	
}
	add_action( 'customize_register', 'dw_grayscale_socialbar' );
